@@ -4,7 +4,7 @@ from .base import BaseSchema
 class Note(BaseSchema):
     title: str
     content: str
-    checked: bool = False  # Whether the note has been reviewed
+    checked: bool = False
 
 
 class NoteManager:
@@ -21,8 +21,9 @@ class NoteManager:
     def __len__(self) -> int:
         return len(self.notes)
 
-    def add(self, note: Note) -> None:
+    def append(self, note: Note) -> None:
         self.notes.append(note)
 
-    def remove(self, note: Note) -> None:
+    def remove(self, index: int) -> None:
+        note = self.notes[index]
         self.notes.remove(note)
